package vn.hongyegroup.yybusiness.ui

import android.os.Build
import android.os.Bundle
import android.view.WindowManager
import androidx.recyclerview.widget.LinearLayoutManager
import com.android.basiclib.base.activity.BaseVVDActivity
import com.android.basiclib.base.vm.EmptyViewModel
import com.android.basiclib.engine.toast.toast
import com.android.basiclib.utils.CommUtils
import com.android.basiclib.utils.StatusBarUtils
import com.android.basiclib.utils.log.MyLogUtils
import dagger.hilt.android.AndroidEntryPoint
import me.yokeyword.indexablerv.IndexableAdapter.OnItemContentClickListener
import vn.hongyegroup.yybusiness.R
import vn.hongyegroup.yybusiness.adapter.AttendanceAdapter
import vn.hongyegroup.yybusiness.databinding.ActivityMainBinding
import vn.hongyegroup.yybusiness.entity.AttendanceBean


/**
 * 应用的首页
 */
@AndroidEntryPoint
class MainActivity : BaseVVDActivity<EmptyViewModel, ActivityMainBinding>() {

    private var mAdapter: AttendanceAdapter? = null

    override fun init(savedInstanceState: Bundle?) {

        //沉浸式
        StatusBarUtils.immersive(this)

        //允许 window 的内容可以上移到刘海屏状态栏
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            val lp = window.attributes
            lp.layoutInDisplayCutoutMode = WindowManager.LayoutParams.LAYOUT_IN_DISPLAY_CUTOUT_MODE_SHORT_EDGES
            window.setAttributes(lp)
        }

        StatusBarUtils.setMargin(mContext, mBinding.statusBarView)


        initRV()
        initListener()
    }

    private fun initRV() {
        mBinding.indexableLayout.setLayoutManager(LinearLayoutManager(this))
        // 设置数据适配器
        mAdapter = AttendanceAdapter(this)
        mBinding.indexableLayout.setAdapter(mAdapter)
        // 设置数据源
        mAdapter?.setDatas(initDatas());
        initDatas()

        // 设置右侧Index的滚动风格
        mBinding.indexableLayout.setOverlayStyle_MaterialDesign(CommUtils.getColor(R.color.button_box_bg))
        mBinding.indexableLayout.setStickyEnable(false)

        // 设置Item监听
        mAdapter?.setOnItemContentClickListener { _, originalPosition, currentPosition, entity ->
            if (originalPosition >= 0) {
                toast("选中:" + entity.staff_name + "  当前位置:" + currentPosition + "  原始所在数组位置:" + originalPosition)

            } else {
                toast("选中Header/Footer:" + entity.staff_name + "  当前位置:" + currentPosition)
            }

        }

        mAdapter!!.setOnItemTitleClickListener { _, currentPosition, indexTitle ->
            toast("选中:$indexTitle  当前位置:$currentPosition")
        }


    }

    //提供RV的数据
    private fun initDatas(): MutableList<AttendanceBean> {
        val list = arrayListOf<AttendanceBean>()
        // 初始化数据
        val contactArray = getResources().getStringArray(R.array.contact_array)
        val mobileArray = getResources().getStringArray(R.array.mobile_array)

        contactArray.forEachIndexed { index, name ->
            val contactEntity = AttendanceBean().apply {
                staff_name = name
                job_date = mobileArray[index]
            }
            list.add(contactEntity)
        }

        MyLogUtils.w("list数据量：${list.size}")

        return list
    }

    //其他的监听
    private fun initListener() {

    }

}
